@@ -13,6 +13,7 @@ use anyhow::Result;
 use path_slash::PathExt;
 use regex::Regex;
 use serde::{Deserialize, Serialize};
+use serde_json::Value;
 use std::collections::{HashMap, HashSet};
 
 mod nx;
@@ -30,6 +31,13 @@ const BUN_CACHE_DIR: &str = "/root/.bun";
 const CYPRESS_CACHE_DIR: &str = "/root/.cache/Cypress";
 const NODE_MODULES_CACHE_DIR: &str = "node_modules/.cache";
 
+#[derive(Serialize, Deserialize, Debug)]
+#[serde(untagged)]
+pub enum Workspaces {
+    Array(Vec<String>),
+    Unknown(Value),
+}
+
 #[derive(Serialize, Deserialize, Default, Debug)]
 pub struct PackageJson {
     pub name: Option<String>,
@@ -42,7 +50,7 @@ pub struct PackageJson {
     #[serde(rename = "type")]
     pub project_type: Option<String>,
 
-    pub workspaces: Option<Vec<String>>,
+    pub workspaces: Option<Workspaces>,
 }
 
 #[derive(Serialize, Deserialize, Default, Debug)]
@@ -203,7 +211,11 @@ impl NodeProvider {
     }
 
     /// Parses the package.json engines field and returns a Nix package if available
-    pub fn get_nix_node_pkg(package_json: &PackageJson, environment: &Environment) -> Result<Pkg> {
+    pub fn get_nix_node_pkg(
+        package_json: &PackageJson,
+        app: &App,
+        environment: &Environment,
+    ) -> Result<Pkg> {
         let env_node_version = environment.get_config_variable("NODE_VERSION");
 
         let pkg_node_version = package_json
@@ -211,7 +223,14 @@ impl NodeProvider {
             .clone()
             .and_then(|engines| engines.get("node").cloned());
 
-        let node_version = env_node_version.or(pkg_node_version);
+        let nvmrc_node_version = if app.includes_file(".nvmrc") {
+            let nvmrc = app.read_file(".nvmrc")?;
+            Some(nvmrc.trim().replace('v', ""))
+        } else {
+            None
+        };
+
+        let node_version = env_node_version.or(pkg_node_version).or(nvmrc_node_version);
 
         let node_version = match node_version {
             Some(node_version) => node_version,
@@ -319,7 +338,7 @@ impl NodeProvider {
         } else {
             PackageJson::default()
         };
-        let node_pkg = NodeProvider::get_nix_node_pkg(&package_json, env)?;
+        let node_pkg = NodeProvider::get_nix_node_pkg(&package_json, app, env)?;
 
         let pm_pkg: Pkg;
         let mut pkgs = Vec::<Pkg>::new();
@@ -478,6 +497,7 @@ mod test {
                     name: Some(String::default()),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new(DEFAULT_NODE_PKG_NAME)
@@ -495,6 +515,7 @@ mod test {
                     engines: Some(engines_node("*")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new(DEFAULT_NODE_PKG_NAME)
@@ -512,6 +533,7 @@ mod test {
                     engines: Some(engines_node("14")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-14_x")
@@ -529,6 +551,7 @@ mod test {
                     engines: Some(engines_node("18.x")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-18_x")
@@ -541,6 +564,7 @@ mod test {
                     engines: Some(engines_node("14.X")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-14_x")
@@ -558,6 +582,7 @@ mod test {
                     engines: Some(engines_node("18.x.x")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-18_x")
@@ -570,6 +595,7 @@ mod test {
                     engines: Some(engines_node("14.X.x")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-14_x")
@@ -587,6 +613,7 @@ mod test {
                     engines: Some(engines_node("18.4.2")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-18_x")
@@ -599,6 +626,7 @@ mod test {
                     engines: Some(engines_node("14.8.x")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-14_x")
@@ -611,6 +639,7 @@ mod test {
                     engines: Some(engines_node("14.x.8")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-14_x")
@@ -628,6 +657,7 @@ mod test {
                     engines: Some(engines_node(">=14.10.3 <16")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?,
             Pkg::new("nodejs-14_x")
@@ -644,6 +674,7 @@ mod test {
                     name: Some(String::default()),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::new(BTreeMap::from([(
                     "NIXPACKS_NODE_VERSION".to_string(),
                     "14".to_string()
@@ -655,6 +686,23 @@ mod test {
         Ok(())
     }
 
+    #[test]
+    fn test_version_from_nvmrc() -> Result<()> {
+        assert_eq!(
+            NodeProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: Some(String::default()),
+                    ..Default::default()
+                },
+                &App::new("examples/node-nvmrc")?,
+                &Environment::default()
+            )?,
+            Pkg::new("nodejs-14_x")
+        );
+
+        Ok(())
+    }
+
     #[test]
     fn test_engine_invalid_version() -> Result<()> {
         // this test now defaults to lts
@@ -665,6 +713,7 @@ mod test {
                     engines: Some(engines_node("15")),
                     ..Default::default()
                 },
+                &App::new("examples/node")?,
                 &Environment::default()
             )?
             .name,
